@@ -33,6 +33,8 @@ RE_ROOT_IN_TES = r"^\/.+$"
 RE_DDDB_TAG = r"^.{1,50}$"
 RE_CONDDB_TAG = r"^.{1,50}$"
 
+RE_COMMENT = r"(.{1,5000})"
+
 BASE_JOB_SCHEMA = {
     "application": Regex(RE_APPLICATION),
     "input": MapPattern(Str(), Any()),
@@ -52,6 +54,10 @@ BASE_JOB_SCHEMA = {
     Optional("conddb_tag"): Regex(RE_CONDDB_TAG),
     Optional("checks"): Seq(Str()),  # TODO: replace this with a regex
     Optional("extra_checks"): Seq(Str()),  # TODO: replace this with a regex
+    # Production submission metadata
+    Optional("comment"): Regex(RE_COMMENT),
+    "priority": Enum(config.allowed_priorities),
+    "completion_percentage": Float(),
 }
 INPUT_SCHEMAS = {
     "bk_query": Map({"bk_query": Str(), Opt("n_test_lfns"): Int()}),
@@ -61,6 +67,8 @@ INPUT_SCHEMAS = {
 DEFAULT_JOB_VALUES = {
     "automatically_configure": False,
     "turbo": False,
+    "completion_percentage": 100,
+    "priority": "1b",
 }
 
 CHECK_TYPE_SCHEMAS = {
@@ -185,6 +193,10 @@ def parse_yaml(rendered_yaml):
         v = _ordered_dict_to_dict(v.data)
 
         production_schema = {}
+        if "comment" in v:
+            raise ValueError(
+                "comment is only allowed to be set in the defaults of the production!"
+            )
         for key, value in BASE_JOB_SCHEMA.items():
             if isinstance(key, Optional):
                 key = key.key
@@ -302,6 +314,14 @@ def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
             if ck not in list(checks_data.keys()):
                 raise ValueError(f"Check {ck} not found in list of defined checks")
 
+    # Validate the completion percentage
+    if not (10 <= job_data["completion_percentage"] <= 100):
+        raise ValueError(
+            f"Validation failed for job '{job_name}', completion_percentage "
+            f"was set to '{job_data['completion_percentage']}', allowed "
+            "values are in the interval [10, 100]."
+        )
+
 
 def _validate_checks_data(checks_data, jobs_data):
     # All checks defined in checks_data should be used by at least 1 job
