@@ -8,11 +8,12 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-
+from copy import deepcopy
 from textwrap import dedent
 
 import pytest
 import strictyaml
+import yaml
 
 import LbAPCommon
 
@@ -24,6 +25,7 @@ OPTIONAL_KEYS = [
     "input_type",
     "dddb_tag",
     "conddb_tag",
+    "comment",
 ]
 
 
@@ -40,6 +42,8 @@ def test_good_no_defaults():
             - $VAR/a.py
         wg: Charm
         inform: a.b@c.d
+        priority: 1a
+        completion_percentage: 99.5
     """
     )
     jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
@@ -54,6 +58,8 @@ def test_good_no_defaults():
     assert jobs_data["job_1"]["automatically_configure"] is False
     assert jobs_data["job_1"]["turbo"] is False
     assert jobs_data["job_1"]["inform"] == "a.b@c.d"
+    assert jobs_data["job_1"]["priority"] == "1a"
+    assert jobs_data["job_1"]["completion_percentage"] == 99.5
     assert checks_data == {}
 
 
@@ -112,6 +118,9 @@ def test_good_with_defaults():
         automatically_configure: yes
         inform:
             - name@example.com
+        priority: 1a
+        completion_percentage: 95.6
+        comment: This production will produce tuples of a, b, c decays for the x analysis in the y working group
 
     job_1:
         application: DaVinci/v45r3
@@ -132,6 +141,8 @@ def test_good_with_defaults():
         automatically_configure: false
         inform:
             - other@example.com
+        priority: 2a
+        completion_percentage: 87.35
     """
     )
     jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
@@ -147,6 +158,12 @@ def test_good_with_defaults():
     assert jobs_data["job_1"]["automatically_configure"] is True
     assert jobs_data["job_1"]["turbo"] is False
     assert jobs_data["job_1"]["inform"] == ["name@example.com"]
+    assert jobs_data["job_1"]["priority"] == "1a"
+    assert jobs_data["job_1"]["completion_percentage"] == 95.6
+    assert (
+        jobs_data["job_1"]["comment"]
+        == "This production will produce tuples of a, b, c decays for the x analysis in the y working group"
+    )
 
     assert jobs_data["job_2"]["application"] == "DaVinci/v44r0"
     assert jobs_data["job_2"]["input"] == {
@@ -158,6 +175,12 @@ def test_good_with_defaults():
     assert jobs_data["job_2"]["automatically_configure"] is False
     assert jobs_data["job_2"]["turbo"] is False
     assert jobs_data["job_2"]["inform"] == ["other@example.com"]
+    assert jobs_data["job_2"]["priority"] == "2a"
+    assert jobs_data["job_2"]["completion_percentage"] == 87.35
+    assert (
+        jobs_data["job_2"]["comment"]
+        == "This production will produce tuples of a, b, c decays for the x analysis in the y working group"
+    )
 
     assert checks_data == {}
 
@@ -770,7 +793,7 @@ def test_bad_missing_key(missing_key):
         }
     }
     del data["job_1"][missing_key]
-    rendered_yaml = strictyaml.YAML(data).as_yaml()
+    rendered_yaml = yaml.safe_dump(data)
     try:
         LbAPCommon.parse_yaml(rendered_yaml)
     except strictyaml.YAMLValidationError as e:
@@ -794,6 +817,7 @@ def test_bad_missing_key(missing_key):
         ("input_type", "2016"),
         ("dddb_tag", ""),
         ("conddb_tag", ""),
+        ("priority", "3a"),
     ],
 )
 def test_bad_invalid_value(key, value):
@@ -810,11 +834,89 @@ def test_bad_invalid_value(key, value):
         }
     }
     data["job_1"][key] = value
-    rendered_yaml = strictyaml.YAML(data).as_yaml()
+    rendered_yaml = yaml.safe_dump(data)
     with pytest.raises(strictyaml.YAMLValidationError, match=key + ":"):
         LbAPCommon.parse_yaml(rendered_yaml)
 
 
+@pytest.mark.parametrize(
+    "key,value",
+    [
+        ("completion_percentage", "ninety-nine"),
+        ("completion_percentage", 100.1),
+        ("completion_percentage", -24.33),
+        ("completion_percentage", 9.9),
+    ],
+)
+def test_bad_invalid_completion_percentage(key, value):
+    data = {
+        "job_1": {
+            "application": "DaVinci/v45r3",
+            "input": {
+                "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+            },
+            "output": "FILETYPE.ROOT",
+            "options": ["options.py"],
+            "wg": "Charm",
+            "inform": "a.b@c.d",
+        }
+    }
+    data["job_1"][key] = value
+    rendered_yaml = yaml.safe_dump(data)
+    with pytest.raises((ValueError, strictyaml.StrictYAMLError)):
+        jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+
+
+def test_completion_percentage_not_in_defaults():
+    job_template = {
+        "application": "DaVinci/v45r3",
+        "input": {
+            "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+        },
+        "output": "FILETYPE.ROOT",
+        "options": ["options.py"],
+        "wg": "Charm",
+        "inform": "a.b@c.d",
+    }
+    data = {
+        "job_1": deepcopy({**job_template, "completion_percentage": 100}),
+        "job_2": deepcopy({**job_template}),
+        "job_3": deepcopy({**job_template, "completion_percentage": 20}),
+    }
+    rendered_yaml = yaml.safe_dump(data)
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    assert jobs_data["job_1"]["completion_percentage"] == 100
+    assert jobs_data["job_2"]["completion_percentage"] == 100
+    assert jobs_data["job_3"]["completion_percentage"] == 20
+
+
+def test_completion_percentage_in_defaults():
+    job_template = {
+        "application": "DaVinci/v45r3",
+        "input": {
+            "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+        },
+        "output": "FILETYPE.ROOT",
+        "options": ["options.py"],
+        "wg": "Charm",
+        "inform": "a.b@c.d",
+    }
+    data = {
+        "defaults": {
+            "completion_percentage": 50,
+        },
+        "job_1": deepcopy({**job_template, "completion_percentage": 100}),
+        "job_2": deepcopy({**job_template}),
+        "job_3": deepcopy({**job_template, "completion_percentage": 20}),
+    }
+    rendered_yaml = yaml.safe_dump(data)
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    assert jobs_data["job_1"]["completion_percentage"] == 100
+    assert jobs_data["job_2"]["completion_percentage"] == 50
+    assert jobs_data["job_3"]["completion_percentage"] == 20
+
+
 def test_filetype_validation():
     from LbAPCommon.parsing import _normalise_filetype
 
